from setuptools import setup, find_packages

setup(
    name="raygun-django-middleware",
    version="1.0.2.dev0",
    description="Raygun Django Middleware",
    author="Mirus Research",
    author_email="frank@mirusresearch.com",
    packages=find_packages(),
    url='https://github.com/mirusresearch/raygun-django-middleware',
    license='MIT license, see LICENSE.txt',
    # install_requires=[
    #     ],
)
